@@ -1,33 +1,20 @@
 /*
-   Copyright (C) 2005-2006,2008-2010 Tom Albers <toma@kde.org>
-   Copyright (C) 2005-2006 Bram Schoenmakers <bramschoenmakers@kde.nl>
-   Copyright (C) 2010 Juan Luis Baptiste <juan.baptiste@gmail.com>
+    SPDX-FileCopyrightText: 2005-2006, 2008-2010 Tom Albers <toma@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Bram Schoenmakers <bramschoenmakers@kde.nl>
+    SPDX-FileCopyrightText: 2010 Juan Luis Baptiste <juan.baptiste@gmail.com>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 
 */
 
 #ifndef RSITimer_H
 #define RSITimer_H
 
-#include <QThread>
 #include <QVector>
 #include <memory>
 
-#include "rsitimercounter.h"
 #include "rsiidletime.h"
+#include "rsitimercounter.h"
 
 /**
  * @class RSITimer
@@ -35,7 +22,7 @@
  * and minimizing of the widget.
  * @author Tom Albers <toma.org>
  */
-class RSITimer : public QThread
+class RSITimer : public QObject
 {
     Q_OBJECT
     friend class RSITimerTest;
@@ -46,21 +33,30 @@ public:
      * @param parent Parent Widget
      * @param name Name
      */
-    explicit RSITimer( QObject *parent = 0 );
+    explicit RSITimer(QObject *parent = 0);
 
     // Check whether the timer is suspended.
-    bool isSuspended() const { return m_state == TimerState::Suspended; }
+    bool isSuspended() const
+    {
+        return m_state == TimerState::Suspended;
+    }
 
-    int tinyLeft() const { return m_tinyBreakCounter->counterLeft(); };
+    int tinyLeft() const
+    {
+        return m_tinyBreakCounter ? m_tinyBreakCounter->counterLeft() : 0;
+    };
 
-    int bigLeft() const { return m_bigBreakCounter->counterLeft(); };
+    int bigLeft() const
+    {
+        return m_bigBreakCounter->counterLeft();
+    };
 
 public slots:
 
     /**
       Reads the configuration and restarts the timer with slotRestart.
     */
-    void updateConfig( bool doRestart = false );
+    void updateConfig(bool doRestart = false);
 
     /**
       Stops the timer activity. This does not imply resetting counters.
@@ -71,7 +67,7 @@ public slots:
       Called when the user suspends RSIBreak from the docker.
       @param suspend If true the timer will suspend, if false the timer will unsuspend.
     */
-    void slotSuspended( bool suspend );
+    void slotSuspended(bool suspend);
 
     /**
       Prepares the timer so that it can start/continue.
@@ -122,20 +118,20 @@ signals:
       @param bigLeft If <=0 a big break is active, else it defines how
       much time is left until the next big break.
     */
-    void updateToolTip( const int tinyLeft, const int bigLeft );
+    void updateToolTip(const int tinyLeft, const int bigLeft);
 
     /**
       Update the time shown on the fullscreen widget.
       @param secondsLeft Shows the user how many seconds are remaining.
     */
-    void updateWidget( int secondsLeft );
+    void updateWidget(int secondsLeft);
 
     /**
       Update the systray icon.
       @param v How much time has passed until a tiny break (relative)
                Varies from 0 to 100.
     */
-    void updateIdleAvg( double v );
+    void updateIdleAvg(double v);
 
     /**
       A request to minimize the fullscreen widget, for example when the
@@ -151,7 +147,7 @@ signals:
       @param nextBreakIsBig True if the break after the next break is a big break.
       We can warn the user in advance.
     */
-    void relax( int sec, bool nextBreakIsBig );
+    void relax(int sec, bool nextBreakIsBig);
 
     /**
       Indicates a tinyBreak is skipped because user was enough idle
@@ -171,15 +167,16 @@ signals:
 private:
     std::unique_ptr<RSIIdleTime> m_idleTimeInstance;
 
+    bool m_suppressable;
     bool m_usePopup;
     bool m_useIdleTimers;
     QVector<int> m_intervals;
 
     enum class TimerState {
-        Suspended = 0,      // user has suspended either via dbus or tray.
-        Monitoring,         // normal cycle, waiting for break to trigger.
-        Suggesting,         // politely suggest to take a break with some patience.
-        Resting             // suggestion ignored, waiting out the break.
+        Suspended = 0, // user has suspended either via dbus or tray.
+        Monitoring, // normal cycle, waiting for break to trigger.
+        Suggesting, // politely suggest to take a break with some patience.
+        Resting // suggestion ignored, waiting out the break.
     } m_state;
 
     std::unique_ptr<RSITimerCounter> m_bigBreakCounter;
@@ -188,26 +185,27 @@ private:
     std::unique_ptr<RSITimerCounter> m_popupCounter;
     std::unique_ptr<RSITimerCounter> m_shortInputCounter;
 
-    void hibernationDetector( const int totalIdle );
-    void suggestBreak( const int time );
+    bool suppressionDetector();
+    void hibernationDetector(const int totalIdle);
+    void suggestBreak(const int time);
     void defaultUpdateToolTip();
     void createTimers();
 
     // This function is called when a break has passed.
     void resetAfterBreak();
 
-    // Start this thread.
-    void run() override;
+    // Start this timer. Used by the constructors.
+    void run();
 
     /**
       Some internal preparations for a fullscreen break window.
       @param breakTime The amount of seconds to break.
       @param nextBreakIsBig Whether the next break will be big.
     */
-    void doBreakNow( const int breakTime, const bool nextBreakIsBig );
+    void doBreakNow(const int breakTime, const bool nextBreakIsBig);
 
     // Constructor for tests.
-    RSITimer( std::unique_ptr<RSIIdleTime> &&_idleTime, const QVector<int> _intervals, const bool _usePopup, const bool _useIdleTimers );
+    RSITimer(std::unique_ptr<RSIIdleTime> &&_idleTime, const QVector<int> _intervals, const bool _usePopup, const bool _useIdleTimers);
 };
 
 #endif
